@@ -11,7 +11,7 @@ pub(crate) fn subcommand_heading(cmd: &clap::Command) -> &str {
 pub(crate) fn about(roff: &mut Roff, cmd: &clap::Command) {
     let name = cmd.get_display_name().unwrap_or_else(|| cmd.get_name());
     let s = match cmd.get_about().or_else(|| cmd.get_long_about()) {
-        Some(about) => format!("{} - {}", name, about),
+        Some(about) => format!("{name} - {about}"),
         None => name.to_owned(),
     };
     roff.text([roman(s)]);
@@ -57,7 +57,7 @@ pub(crate) fn synopsis(roff: &mut Roff, cmd: &clap::Command) {
         };
 
         if matches!(opt.get_action(), ArgAction::Count) {
-            line.push(roman("..."))
+            line.push(roman("..."));
         }
         line.push(roman(" "));
     }
@@ -88,9 +88,7 @@ pub(crate) fn synopsis(roff: &mut Roff, cmd: &clap::Command) {
     roff.text(line);
 }
 
-pub(crate) fn options(roff: &mut Roff, cmd: &clap::Command) {
-    let items: Vec<_> = cmd.get_arguments().filter(|i| !i.is_hide_set()).collect();
-
+pub(crate) fn options(roff: &mut Roff, items: &[&Arg]) {
     for opt in items.iter().filter(|a| !a.is_positional()) {
         let mut header = match (opt.get_short(), opt.get_long()) {
             (Some(short), Some(long)) => {
@@ -101,10 +99,28 @@ pub(crate) fn options(roff: &mut Roff, cmd: &clap::Command) {
             (None, None) => vec![],
         };
 
-        if opt.get_num_args().expect("built").takes_values() {
-            if let Some(value) = &opt.get_value_names() {
-                header.push(roman("="));
-                header.push(italic(value.join(" ")));
+        let arg_range = opt.get_num_args().expect("built");
+        if arg_range.takes_values() {
+            if let Some(value_names) = &opt.get_value_names() {
+                let (lhs, rhs) = option_value_markers(opt);
+
+                header.push(roman(lhs));
+                for (i, name) in value_names.iter().enumerate() {
+                    if i > 0 {
+                        header.push(italic(" "));
+                    }
+
+                    let mut val = format!("<{name}>");
+
+                    // If this is the last value and it's variadic, add "..."
+                    let is_last = i == value_names.len() - 1;
+
+                    if is_last && arg_range.max_values() > value_names.len() {
+                        val.push_str("...");
+                    }
+                    header.push(italic(val));
+                }
+                header.push(roman(rhs));
             }
         }
 
@@ -165,7 +181,7 @@ pub(crate) fn options(roff: &mut Roff, cmd: &clap::Command) {
             roff.control("RE", []);
         }
 
-        possible_options(roff, pos, arg_help_written)
+        possible_options(roff, pos, arg_help_written);
     }
 }
 
@@ -241,7 +257,7 @@ fn subcommand_markers(cmd: &clap::Command) -> (&'static str, &'static str) {
     markers(cmd.is_subcommand_required_set())
 }
 
-fn option_markers(opt: &clap::Arg) -> (&'static str, &'static str) {
+fn option_markers(opt: &Arg) -> (&'static str, &'static str) {
     markers(opt.is_required_set())
 }
 
@@ -253,6 +269,31 @@ fn markers(required: bool) -> (&'static str, &'static str) {
     }
 }
 
+fn option_value_markers(arg: &Arg) -> (&'static str, &'static str) {
+    let range = arg.get_num_args().expect("built");
+
+    if !range.takes_values() {
+        return ("", ""); // no value, so nothing to render
+    }
+
+    let required = range.min_values() > 0;
+    let require_equals = arg.is_require_equals_set();
+
+    match (required, require_equals) {
+        // Required, no equals: <VALUE>
+        (true, false) => (" ", ""),
+
+        // Optional, no equals: [<VALUE>]
+        (false, false) => (" [", "]"),
+
+        // Optional, with equals: [=<VALUE>]
+        (false, true) => ("[=", "]"),
+
+        // Required, with equals
+        (true, true) => ("=", ""),
+    }
+}
+
 fn short_option(opt: char) -> Inline {
     bold(format!("-{opt}"))
 }
@@ -261,7 +302,7 @@ fn long_option(opt: &str) -> Inline {
     bold(format!("--{opt}"))
 }
 
-fn option_help(opt: &clap::Arg) -> Option<&clap::builder::StyledStr> {
+fn option_help(opt: &Arg) -> Option<&clap::builder::StyledStr> {
     if !opt.is_hide_long_help_set() {
         let long_help = opt.get_long_help();
         if long_help.is_some() {
@@ -275,7 +316,7 @@ fn option_help(opt: &clap::Arg) -> Option<&clap::builder::StyledStr> {
     None
 }
 
-fn option_environment(opt: &clap::Arg) -> Option<Vec<Inline>> {
+fn option_environment(opt: &Arg) -> Option<Vec<Inline>> {
     if opt.is_hide_env_set() {
         return None;
     } else if let Some(env) = opt.get_env() {
@@ -289,7 +330,7 @@ fn option_environment(opt: &clap::Arg) -> Option<Vec<Inline>> {
     None
 }
 
-fn option_default_values(opt: &clap::Arg) -> Option<String> {
+fn option_default_values(opt: &Arg) -> Option<String> {
     if opt.is_hide_default_value_set() || !opt.get_num_args().expect("built").takes_values() {
         return None;
     } else if !opt.get_default_values().is_empty() {
@@ -306,7 +347,7 @@ fn option_default_values(opt: &clap::Arg) -> Option<String> {
     None
 }
 
-fn get_possible_values(arg: &clap::Arg) -> Option<(Vec<String>, bool)> {
+fn get_possible_values(arg: &Arg) -> Option<(Vec<String>, bool)> {
     if arg.is_hide_possible_values_set() {
         return None;
     }
